<!-- SPDX-FileCopyrightText: 2025 Semiotic AI, Inc. -->
<!-- SPDX-License-Identifier: MIT -->

# Types

Response types and data classes.

## Response Types

::: agentium_sdk.ConnectIdentityResponse

::: agentium_sdk.OAuthTokenResponse

::: agentium_sdk.Badge

::: agentium_sdk.WalletChallengeResponse

## Chain Identifiers

::: agentium_sdk.Caip2

::: agentium_sdk.Caip2Error

## Enums

::: agentium_sdk.GrantType
